AceController<T> class

Inheritance
Implementers

Constructors

AceController({double? maxScale, double? pointSpace, void onScrollBoundary(ScrollBoundary boundary)?, double paddingRight = 0, required int maxLength, double pointWidth = 1})

Properties

catchController CatchController
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastScrollBoundary ScrollBoundary?
getter/setter pair
maxLength int
final
maxScale double?
final
onScrollBoundary → void Function(ScrollBoundary boundary)?
final
paddingRight double
final
pointSpace double?
getter/setter pair
pointWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<T>
final

Methods

addAll(List<T> vals) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addValue(T value) → void
attach(AceState<AceWidget, dynamic> s) → void
calculateSpace() → void
clear() → void
didUpdateWidget() → void
dispose() → void
Discards any resources used by the object.
inherited
getLastScale() double
getMinScale() double
getMinScrollX() double
getPressOffset() Offset?
getScale() double
getScrollX() double
getSpace() double
initBoundary() → void
isKChart() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChanged() → void
notifyListeners() → void
Call all the registered listeners.
inherited
onHorizontalDragCancel() → void
onHorizontalDragEnd() → void
onHorizontalDragUpdate(DragUpdateDetails details) → void
onScaleEnd(ScaleEndDetails details) → void
onScaleStart(ScaleStartDetails details) → void
onScaleUpdate(ScaleUpdateDetails details) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replace(int index, T val) → void
replaceAll(List<T> vals) → void
reset() → void
setInnerWidth(double width) → void
setScrollX(double x) → void
sumTotalWidth() → void
testMostRightNotifyChanged(void next()) → void
toString() String
A string representation of this object.
inherited
updatePressOffset(Offset? offset, [bool isLong = false]) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited